#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_SPLATTED_PROD_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_SPLATTED_PROD_HPP_INCLUDED

#include <boost/simd/swar/include/functions/simd/splatted_prod.hpp>

#endif
